===============
Algebras Module
===============

Introduction
------------

The Algebras module for SymPy provides support
for basic algebraic operations on Quaternions.

Quaternion Reference
--------------------

.. automodule:: sympy.algebras

This section lists the classes implemented by the Algebras module.

.. autoclass:: Quaternion
   :members:
